@@ -7,20 +7,15 @@ from .jwt_pomes import (
     jwt_issue_token, jwt_issue_tokens, jwt_refresh_tokens,
     jwt_get_claims, jwt_validate_token, jwt_revoke_token
 )
-from .jwt_providers import (
-    provider_register, provider_get_token
-)
 
 __all__ = [
-    # jwt_constants
+    # jwt_config
     "JwtConfig", "JwtDbConfig", "JwtAlgorithm",
     # jwt_pomes
     "jwt_needed", "jwt_verify_request",
     "jwt_assert_account", "jwt_set_account", "jwt_remove_account",
     "jwt_issue_token", "jwt_issue_tokens", "jwt_refresh_tokens",
-    "jwt_get_claims", "jwt_validate_token", "jwt_revoke_token",
-    # jwt_providers
-    "provider_register", "provider_get_token"
+    "jwt_get_claims", "jwt_validate_token", "jwt_revoke_token"
 ]
 
 from importlib.metadata import version
