@@ -52,7 +52,7 @@ def jwt_verify_request(request: Request) -> Response:
     # validate the authorization token
     bad_token: bool = True
     if auth_header and auth_header.startswith("Bearer "):
-        # yes, extract and validate the JWT access token
+        # extract and validate the JWT access token
         token: str = auth_header.split(" ")[1]
         claims: dict[str, Any] = jwt_validate_token(token=token,
                                                     nature="A")
@@ -224,14 +224,17 @@ def jwt_validate_token(token: str,
                 #   InvalidIssuedAtError: 'iat' claim is non-numeric
                 #   MissingRequiredClaimError: a required claim is not contained in the claimset
                 payload: dict[str, Any] = jwt.decode(jwt=token,
-                                                     options={
-                                                         "verify_signature": True,
-                                                         "verify_exp": True,
-                                                         "verify_nbf": True
-                                                     },
                                                      key=token_decoder,
-                                                     require=["iat", "iss", "exp", "sub"],
-                                                     algorithms=token_alg)
+                                                     algorithms=token_alg,
+                                                     options={
+                                                         "require": ["iat", "iss", "exp", "sub"],
+                                                         "verify_aud": False,
+                                                         "verify_exp": True,
+                                                         "verify_iat": True,
+                                                         "verify_iss": False,
+                                                         "verify_nbf": True,
+                                                         "verify_signature": True
+                                                     })
                 if account_id and payload.get("sub") != account_id:
                     if logger:
                         logger.error(msg=f"Token does not belong to account '{account_id}'")
@@ -505,7 +508,7 @@ def jwt_refresh_tokens(account_id: str,
 
 def jwt_get_claims(token: str,
                    errors: list[str] = None,
-                   logger: Logger = None) -> dict[str, Any] | None:
+                   logger: Logger = None) -> dict[str, dict[str, Any]] | None:
     """
     Retrieve the claims set of a JWT *token*.
 
@@ -520,8 +523,6 @@ def jwt_get_claims(token: str,
           "kid": "A1234"
         },
         "payload": {
-          "valid-from": <YYYY-MM-DDThh:mm:ss+00:00>
-          "valid-until": <YYYY-MM-DDThh:mm:ss+00:00>
           "birthdate": "1980-01-01",
           "email": "jdoe@mail.com",
           "exp": 1516640454,
@@ -539,13 +540,13 @@ def jwt_get_claims(token: str,
         }
       }
 
-    :param token: the token to be inspected for claims
+    :param token: the reference token
     :param errors: incidental error messages
     :param logger: optional logger
     :return: the token's claimset, or *None* if error
     """
     # initialize the return variable
-    result: dict[str, Any] | None = None
+    result: dict[str, dict[str, Any]] | None = None
 
     if logger:
         logger.debug(msg="Retrieve claims for token")
@@ -562,7 +563,7 @@ def jwt_get_claims(token: str,
         exc_err: str = exc_format(exc=e,
                                   exc_info=sys.exc_info())
         if logger:
-            logger.error(msg=f"Error retrieving the token's claimsn: {exc_err}")
+            logger.error(msg=f"Error retrieving the token's claims: {exc_err}")
         if isinstance(errors, list):
             errors.append(exc_err)
 
